@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Unevaluated;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Unevaluated vocabulary
 
-our $VERSION = '0.605';
+our $VERSION = '0.632';
 
 use 5.020;
 use Moo;
@@ -16,7 +16,11 @@ use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
-use List::Util 1.45 qw(any max);
+no if "$]" >= 5.041009, feature => 'smartmatch';
+no feature 'switch';
+use List::Util 'max';
+use if "$]" < 5.041010, 'List::Util' => 'any';
+use if "$]" >= 5.041010, experimental => 'keyword_any';
 use JSON::Schema::Modern::Utilities qw(is_type jsonp local_annotations E A abort true);
 use namespace::clean;
 
@@ -30,7 +34,7 @@ sub evaluation_order ($class) { 7 }
 
 # This vocabulary should be evaluated after the Applicator vocabulary.
 sub keywords ($class, $spec_version) {
-  die 'Unevaluated not implemented in '.$spec_version if $spec_version =~ /^draft(?:[467]|2019-09)$/;
+  die 'Unevaluated not implemented in '.$spec_version if $spec_version =~ /^draft(?:[467]|2019-09)\z/;
   qw(unevaluatedItems unevaluatedProperties);
 }
 
@@ -39,19 +43,17 @@ sub _traverse_keyword_unevaluatedItems ($class, $schema, $state) {
 }
 
 sub _eval_keyword_unevaluatedItems ($class, $data, $schema, $state) {
+  return 1 if not is_type('array', $data);
+
   # these should never happen
   die '"unevaluatedItems" keyword present, but annotation collection is disabled'
     if not $state->{collect_annotations};
-  die '"unevaluatedItems" keyword present, but short_circuit is enabled: results unreliable'
-    if $state->{short_circuit};
-
-  return 1 if not is_type('array', $data);
 
   my @annotations = local_annotations($state);
 
   # a relevant keyword already produced a 'true' annotation at this location
   my @boolean_annotation_keywords =
-    $state->{spec_version} eq 'draft2019-09' ? qw(items additionalItems unevaluatedItems)
+    $state->{specification_version} eq 'draft2019-09' ? qw(items additionalItems unevaluatedItems)
       : qw(prefixItems items contains unevaluatedItems);
   my %bools; @bools{@boolean_annotation_keywords} = (1)x@boolean_annotation_keywords;
   return 1
@@ -60,13 +62,13 @@ sub _eval_keyword_unevaluatedItems ($class, $data, $schema, $state) {
 
   # otherwise, evaluate at every instance item greater than the max of all 'prefixItems'/numeric
   # 'items' annotations that isn't in a 'contains' annotation
-  my $max_index_annotation_keyword = $state->{spec_version} eq 'draft2019-09' ? 'items' : 'prefixItems';
+  my $max_index_annotation_keyword = $state->{specification_version} eq 'draft2019-09' ? 'items' : 'prefixItems';
   my $last_index = max(-1, grep is_type('integer', $_),
     map +($_->{keyword} eq $max_index_annotation_keyword ? $_->{annotation} : ()), @annotations);
 
   return 1 if $last_index == $data->$#*;
 
-  my @contains_annotation_indexes = $state->{spec_version} eq 'draft2019-09' ? ()
+  my @contains_annotation_indexes = $state->{specification_version} eq 'draft2019-09' ? ()
     : map +($_->{keyword} eq 'contains' ? $_->{annotation}->@* : ()), @annotations;
 
   my $valid = 1;
@@ -80,7 +82,7 @@ sub _eval_keyword_unevaluatedItems ($class, $data, $schema, $state) {
     else {
       if ($class->eval($data->[$idx], $schema->{unevaluatedItems},
           +{ %$state, data_path => $state->{data_path}.'/'.$idx,
-            schema_path => $state->{schema_path}.'/unevaluatedItems',
+            keyword_path => $state->{keyword_path}.'/unevaluatedItems',
             collect_annotations => $state->{collect_annotations} & ~1 })) {
         next;
       }
@@ -100,13 +102,11 @@ sub _traverse_keyword_unevaluatedProperties ($class, $schema, $state) {
 }
 
 sub _eval_keyword_unevaluatedProperties ($class, $data, $schema, $state) {
+  return 1 if not is_type('object', $data);
+
   # these should never happen
   die '"unevaluatedProperties" keyword present, but annotation collection is disabled'
     if not $state->{collect_annotations};
-  die '"unevaluatedProperties" keyword present, but short_circuit is enabled: results unreliable'
-    if $state->{short_circuit};
-
-  return 1 if not is_type('object', $data);
 
   my @evaluated_properties = map {
     my $keyword = $_->{keyword};
@@ -128,7 +128,7 @@ sub _eval_keyword_unevaluatedProperties ($class, $data, $schema, $state) {
     else {
       if ($class->eval($data->{$property}, $schema->{unevaluatedProperties},
           +{ %$state, data_path => jsonp($state->{data_path}, $property),
-            schema_path => $state->{schema_path}.'/unevaluatedProperties',
+            keyword_path => $state->{keyword_path}.'/unevaluatedProperties',
             collect_annotations => $state->{collect_annotations} & ~1 })) {
         next;
       }
@@ -157,7 +157,7 @@ JSON::Schema::Modern::Vocabulary::Unevaluated - Implementation of the JSON Schem
 
 =head1 VERSION
 
-version 0.605
+version 0.632
 
 =head1 DESCRIPTION
 
@@ -174,6 +174,14 @@ JSON Schema Draft 2019-09 "Applicator" vocabulary, indicated in metaschemas
 with the URI C<https://json-schema.org/draft/2019-09/vocab/applicator> and formally specified in
 L<https://datatracker.ietf.org/doc/html/draft-handrews-json-schema-02#section-9>.
 
+=head1 GIVING THANKS
+
+=for stopwords MetaCPAN GitHub
+
+If you found this module to be useful, please show your appreciation by
+adding a +1 in L<MetaCPAN|https://metacpan.org/dist/JSON-Schema-Modern>
+and a star in L<GitHub|https://github.com/karenetheridge/JSON-Schema-Modern>.
+
 =head1 SUPPORT
 
 Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Modern/issues>.
@@ -196,4 +204,6 @@ This software is copyright (c) 2020 by Karen Etheridge.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+Some schema files have their own licence, in share/LICENSE.
+
 =cut
